"""Machine learning utilities such as a standard definition of a :class:`NeuralNet` and :class:`Optimizer`"""

from .activation import sigmoid, softmax, relu
from .constants import LIB_URI
from .service import ML
from .variable import Variable
